import { Nullable } from './types';
/**
 *  expectTableRowCountToBeGreaterThan expects a tableData as processed by convertHTMLTable.
 * the expectation will check the total row count of the table to be greater than.
 *
 * | one | two |
 * | 1   | 3   |
 * | 2   | 100 |
 *
 * expectTableRowCountToBeGreaterThan(dt, 3) this will fail as row count is 2
 */
export declare const expectTableRowCountToBeGreaterThan: (tableData: {
    [key: string]: string;
}[] | null, expectedLength: number) => void;
/**
 * expectColumnValuesToMatchRegex expects a tableData as processed by convertHTMLTable.
 * The expectation will match the column provided with a regular expression pattern.
 *
 * | one | two |
 * | 1   | 3   |
 * | 2   | 100 |
 *
 * expectColumnValuesToMatchRegex(dt, "two", "\\d\\d") this will fail as {"two":"100"} has 3 digits
 *
 * "Write Once, Never Read" - Use sparingly, add expectations where RegExs can be replaced.
 */
export declare const expectColumnValuesToMatchRegex: (tableData: {
    [key: string]: string;
}[] | null, columnHeader: string, regexPattern: string) => void;
/**
 * expectTableRowCountToBeGreaterThan expects a tableData as processes by convertHTMLTable.
 * The expectation will match the column provided with an range.
 *
 * | one | two |
 * | 1   | 3   |
 * | 2   | 100 |
 *
 * expectColumnValuesToBeInRange(dt, "two", 0, 4) this will fail as {"two":"100"} is greater than 4
 */
export declare const expectColumnValuesToBeInRange: (tableData: {
    [key: string]: string;
}[] | null, columnHeader: string, minValue: number, maxValue: number) => void;
/**
 * expectColumnValuesToBeNumbers expects a tableData as processed by convertHTMLTable.
 * The expectation will check the column values are numbers
 *
 * | one | two |
 * | 1   | 3   |
 * | 2   | 1e  |
 *
 * expectColumnValuesToBeNumbers(dt, "two") this will fail as {"two":"1e"} is not a number
 */
export declare const expectColumnValuesToBeNumbers: (tableData: {
    [key: string]: string;
}[] | null, columnHeader: string) => void;
/**
 * expectColumnToMatchWhenFilteredBy: Expects a tableData generated by convertHTMLTable().
 * This expectation is attempting to match against a column/key pairing whilst a filter
 * has been applied. There is also no validation on checking the correct columns names.
 *
 * @example
 * | col_1 | col_2 |
 * | ------| ----- |
 * | 1     | 3     |
 * | 2     | 1e    |
 *
 * expectColumnToMatchIf(dt, "col_1", "2", "col_2", "xyz");
 *
 * This will Fail as {"col_1":"2"} is located however {"col_2":"xyz"} is not found.
 */
export declare const expectColumnToMatchWhenFilteredBy: (tableData: {
    [key: string]: string;
}[] | null, targetColumn: string, targetValue: Nullable<string>, filterColumn: string, filterValue: Nullable<string>) => void;
/**
 * GroupType for usage with:
 *  - expectColumnToMatchGroupWhenFilteredBy
 */
export type GroupType = {
    filterColumn: string;
    filterValue: Nullable<string>;
};
/**
 * expectColumnToMatchGroupWhenFilteredBy uses an array of types GroupType
 * to cycle through and pass the items to expectColumnToMatchWhenFilteredBy.
 *
 * @example
 *
 * | col_1 | col_2 | col_3 |
 * | ------| ----- | ----- |
 * | 1     | a     | b     |
 *
 * const group: GroupType[] = [
 *     { filterColumn: "col_2", filterValue: "a" },
 *     { filterColumn: "col_3", filterValue: "a" },
 * ];
 *
 * expectColumnToMatchGroupWhenFilteredBy(dt, "col_1", "1", group)
 *
 * This will fail as {"col_2": "a"} is OK however {"col_3": "a"} should be "b"
 */
export declare const expectColumnToMatchGroupWhenFilteredBy: (tableData: {
    [key: string]: string;
}[] | null, targetColumn: string, targetValue: Nullable<string>, filterGroup: GroupType[]) => void;
/**
 * expectColumnToNotMatch: Expects a tableData generated by convertHTMLTable().
 * This expectation confirms that a column no longer contains a match. This
 * expectation is designed around checking a row is no longer available. Such
 * as when a record has been deleted or archived.
 *
 * @example
 * | col_1 | col_2 |
 * | ------| ----- |
 * | 1     | 3     |
 * | 2     | 1e    |
 *
 * expectColumnToNotMatch(dt, "col_1", "2");
 *
 * This will Fail as {"col_1":"2"} is found and should not be.
 */
export declare const expectColumnToNotMatch: (tableData: {
    [key: string]: string;
}[] | null, targetColumn: string, targetValue: string | undefined) => void;
/**
 * expectTableRowCountToBe: Expects a tableData as processed by convertHTMLTable().
 * The expectation will match the row count.
 *
 * @example
 * | col_1 | col_2 |
 * | ------| ----- |
 * | 1     | 3     |
 * | 2     | 1e    |
 *
 * expectTableRowCountToBe(dt, 3);
 *
 * This will fail as row count should be 2
 */
export declare const expectTableRowCountToBe: (tableData: {
    [key: string]: string;
}[] | null, expectedLength: number) => void;
/**
 * expectColumnToBeValue expects only 1 table row and
 * the column value should match the provided value.
 *
 * @example
 * | col_1 | col_2 |
 * | ------| ----- |
 * | 1     | 3     |
 *
 * expectColumnToBeValue(dt, col_2, 2);
 *
 * This will fail as the column value should be 3.
 */
export declare const expectColumnToBeValue: (tableData: {
    [key: string]: string;
}[] | null, column: string, value: string) => void;
/**
 * expectColumnGroupToBeValue expects only 1 table row and
 * the column value in a group should match the provided.
 * Exceptions are made when the filterValue is null/undefined.
 *
 * @example
 * | col_1 | col_2 |
 * | ------| ----- |
 * | 1     | 3     |
 *
 * expectColumnToBeValue(dt, col_2, 2);
 *
 * This will fail as the column value should be 3.
 */
export declare const expectColumnGroupToBeValue: (tableData: {
    [key: string]: string;
}[] | null, filterGroup: GroupType[]) => void;
/**
 * expectColumnGroupToBeValues is the multiple grouped check,
 * using expectColumnGroupToBeValue for each row. Table Data
 * is the same and filterGroups is an array of groups. FilterGroups
 * and the TableData must be the same length.
 *
 * @example
 * See expectColumnGroupToBeValue
 */
export declare const expectColumnGroupToBeValues: (tableData: {
    [key: string]: string;
}[] | null, filterGroups: GroupType[][]) => void;
/**
 * expectTableToNotMatch will convert the tables key/values
 * into a string and compares the two for equality.
 *
 * @param tableData1
 * @param tableData2
 *
 * @example
 *
 * table1: | col_1 | col_2 | table2: | col_1 | col_2 |
 *         | ------| ----- |         | ------| ----- |
 *         | 1     | 3     |         | 1     | 3     |
 *
 * expectTableToNotMatch(table1, table2);
 *
 * This will fail as the two tables are the same
 */
export declare const expectTableToNotMatch: (tableData1: {
    [key: string]: string;
}[] | null, tableData2: {
    [key: string]: string;
}[] | null) => void;
/**
 * expectTableToMatch will convert the tables key/values
 * into a string and compares the two for equality.
 *
 * @param tableData1
 * @param tableData2
 *
 * @example
 *
 * table1: | col_1 | col_2 | table2: | col_1 | col_2 |
 *         | ------| ----- |         | ------| ----- |
 *         | 1     | 3     |         | 1     | 4     |
 *
 * expectTableToMatch(table1, table2);
 *
 * This will fail as the two tables are different
 */
export declare const expectTableToMatch: (tableData1: {
    [key: string]: string;
}[] | null, tableData2: {
    [key: string]: string;
}[] | null) => void;
